@@ -4,8 +4,10 @@ test_that("the dfs algorithm is functional", {
 
   # Create a random graph
   graph <-
-    create_random_graph(
-      n = 10, m = 10,
+    create_graph() %>%
+    add_gnm_graph(
+      n = 10,
+      m = 10,
       set_seed = 23)
 
   # Perform a depth-first search of the graph,
@@ -23,12 +25,12 @@ test_that("the dfs algorithm is functional", {
   # Expect the length of the vector to be the
   # same as the number of nodes in the graph
   expect_equal(
-    length(dfs_all), node_count(graph))
+    length(dfs_all), count_nodes(graph = graph))
 
   # Expect that certain values are returned
   expect_equal(
     dfs_all,
-    c(1, 7, 2, 10, 5, 6, 9, 3, 4, 8))
+    c(1, 5, 4, 8, 3, 2, 6, 10, 9, 7))
 
   # If not specifying a starting node, the function
   # will begin the search from a random node
@@ -43,7 +45,7 @@ test_that("the dfs algorithm is functional", {
   # Expect the length of the vector to be the
   # same as the number of nodes in the graph
   expect_equal(
-    length(dfs_all_no_start), node_count(graph))
+    length(dfs_all_no_start), count_nodes(graph = graph))
 
   # Using `direction = "in"` to cause the dfs
   # routine to visit nodes along inward edges
@@ -60,12 +62,12 @@ test_that("the dfs algorithm is functional", {
   # Expect the length of the vector to be the
   # same as the number of nodes in the graph
   expect_equal(
-    length(dfs_in), node_count(graph))
+    length(dfs_in), count_nodes(graph = graph))
 
   # Expect that certain values are returned
   expect_equal(
     dfs_in,
-    c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10))
+    c(1, 5, 2, 3, 10, 4, 6, 7, 8, 9))
 
   # Using `direction = "out"` results in the dfs
   # moving along solely outward edges
@@ -82,12 +84,12 @@ test_that("the dfs algorithm is functional", {
   # Expect the length of the vector to be the
   # same as the number of nodes in the graph
   expect_equal(
-    length(dfs_out), node_count(graph))
+    length(dfs_out), count_nodes(graph = graph))
 
   # Expect that certain values are returned
   expect_equal(
     dfs_out,
-    c(1, 7, 9, 2, 10, 3, 4, 5, 6, 8))
+    c(1, 2, 3, 6, 8, 10, 4, 9, 5, 7))
 
   # Expect an error if performing dfs without
   # a node data frame in the graph
@@ -106,8 +108,10 @@ test_that("the bfs algorithm is functional", {
 
   # Create a random graph
   graph <-
-    create_random_graph(
-      n = 15, m = 15,
+    create_graph() %>%
+    add_gnm_graph(
+      n = 10,
+      m = 10,
       set_seed = 23)
 
   # Perform a breadth-first search of the graph,
@@ -125,12 +129,12 @@ test_that("the bfs algorithm is functional", {
   # Expect the length of the vector to be the
   # same as the number of nodes in the graph
   expect_equal(
-    length(bfs_all), node_count(graph))
+    length(bfs_all), count_nodes(graph = graph))
 
   # Expect that certain values are returned
   expect_equal(
     bfs_all,
-    c(1, 12, 15, 14, 3, 5, 8, 2, 4, 9, 6, 7, 10, 11, 13))
+    c(1, 5, 4, 10, 8, 9, 3, 2, 6, 7))
 
   # If not specifying a starting node, the function
   # will begin the search from a random node
@@ -146,7 +150,7 @@ test_that("the bfs algorithm is functional", {
   # same as the number of nodes in the graph
   expect_equal(
     length(bfs_all_no_start),
-    node_count(graph))
+    count_nodes(graph = graph))
 
   # Using `direction = "in"` to cause the bfs
   # routine to visit nodes along inward edges
@@ -163,12 +167,12 @@ test_that("the bfs algorithm is functional", {
   # Expect the length of the vector to be the
   # same as the number of nodes in the graph
   expect_equal(
-    length(bfs_in), node_count(graph))
+    length(bfs_in), count_nodes(graph = graph))
 
   # Expect that certain values are returned
   expect_equal(
     bfs_in,
-    c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15))
+    c(1, 5, 2, 3, 10, 4, 6, 7, 8, 9))
 
   # Using `direction = "out"` results in the bfs
   # moving along solely outward edges
@@ -185,12 +189,12 @@ test_that("the bfs algorithm is functional", {
   # Expect the length of the vector to be the
   # same as the number of nodes in the graph
   expect_equal(
-    length(bfs_out), node_count(graph))
+    length(bfs_out), count_nodes(graph = graph))
 
   # Expect that certain values are returned
   expect_equal(
     bfs_out,
-    c(1, 12, 15, 2, 3, 4, 14, 5, 9, 6, 8, 10, 11, 13, 7))
+    c(1, 2, 3, 6, 8, 10, 4, 9, 5, 7))
 
   # Expect an error if performing bfs without
   # a node data frame in the graph
